@@ -39,6 +39,7 @@ from duplicity import file_naming
 from duplicity import globals
 from duplicity import log
 from duplicity import urlparse_2_5 as urlparser
+from duplicity import progress
 
 from duplicity.util import exception_traceback
 
@@ -193,7 +194,8 @@ def _ensure_urlparser_initialized():
                                      'webdav', 'webdavs',
                                      'gdocs',
                                      'http', 'https',
-                                     'imap', 'imaps']
+                                     'imap', 'imaps',
+                                     'mega']
 
             # Do not transform or otherwise parse the URL path component.
             urlparser.uses_query = []
@@ -354,11 +356,11 @@ def retry_fatal(fn):
             self.retry_count = n+1
             return fn(self, *args)
         except Exception, e:
+            log.Debug("Backtrace of previous error: %s"
+                        % exception_traceback())
             log.FatalError("Giving up after %s attempts. %s: %s"
                          % (self.retry_count, e.__class__.__name__, str(e)),
                           log.ErrorCode.backend_error)
-            log.Debug("Backtrace of previous error: %s"
-                        % exception_traceback())
         self.retry_count = 0
 
     return _retry_fatal
