@@ -155,8 +155,19 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname, key.get_
             self.config['identityfile'] = keyfilename
         ## ensure ~ is expanded and identity exists in dictionary
         if 'identityfile' in self.config:
-            self.config['identityfile'] = os.path.expanduser(
-                                            self.config['identityfile'])
+            if not isinstance(self.config['identityfile'], list):
+                # Paramiko 1.9.0 and earlier do not support multiple
+                # identity files when parsing config files and always
+                # return a string; later versions always return a list,
+                # even if there is only one file given.
+                #
+                # All recent versions seem to support *using* multiple
+                # identity files, though, so to make things easier, we
+                # simply always use a list.
+                self.config['identityfile'] = [self.config['identityfile']]
+
+            self.config['identityfile'] = [os.path.expanduser(i) for i in
+                    self.config['identityfile']]
         else:
             self.config['identityfile'] = None
 
@@ -352,12 +363,10 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname, key.get_
     def delete(self, filename_list):
         """deletes all files in the list on the remote side. In scp mode unavoidable quoting issues
         will cause failures if filenames containing single quotes are encountered."""
-        for n in range(1, globals.num_retries+1):
-            if n > 1:
-                # sleep before retry
-                time.sleep(self.retry_delay)
-            try:
-                for fn in filename_list:
+        for fn in filename_list:
+            # Try to delete each file several times before giving up completely.
+            for n in range(1, globals.num_retries+1):
+                try:
                     if (globals.use_scp):
                         self.runremote("rm '%s/%s'" % (self.remote_dir,fn),False,"scp rm ")
                     else:
@@ -365,11 +374,15 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname, key.get_
                             self.sftp.remove(fn)
                         except Exception, e:
                             raise BackendException("sftp rm %s failed: %s" % (fn,e))
-            except Exception, e:
-                if n == globals.num_retries:
-                    log.FatalError(str(e), log.ErrorCode.backend_error)
-                else:
-                    log.Warn("%s (Try %d of %d) Will retry in %d seconds." % (e,n,globals.num_retries,self.retry_delay))
+
+                    # If we get here, we deleted this file successfully. Move on to the next one.
+                    break
+                except Exception, e:
+                    if n == globals.num_retries:
+                        log.FatalError(str(e), log.ErrorCode.backend_error)
+                    else:
+                        log.Warn("%s (Try %d of %d) Will retry in %d seconds." % (e,n,globals.num_retries,self.retry_delay))
+                        time.sleep(self.retry_delay)
 
     def runremote(self,cmd,ignoreexitcode=False,errorprefix=""):
         """small convenience function that opens a shell channel, runs remote command and returns
