@@ -257,6 +257,8 @@ def parse_cmdline_options(arglist):
     parser.add_option("--asynchronous-upload", action="store_const", const=1,
                       dest="async_concurrency")
 
+    parser.add_option("--compare-data", action="store_true")
+
     # config dir for future use
     parser.add_option("--config-dir", type="file", metavar=_("path"),
                       help=optparse.SUPPRESS_HELP)
@@ -400,6 +402,9 @@ def parse_cmdline_options(arglist):
                       dest="", action="callback",
                       callback=lambda o, s, v, p: log.add_file(v))
 
+    # Maximum block size for large files
+    parser.add_option("--max-blocksize", type="int", metavar=_("number"))
+
     # TRANSL: Used in usage help (noun)
     parser.add_option("--name", dest="backup_name", metavar=_("backup name"))
 
@@ -431,6 +436,12 @@ def parse_cmdline_options(arglist):
                       callback=lambda o, s, v, p: (setattr(p.values, o.dest, True),
                                                    old_fn_deprecation(s)))
 
+    # Used to display the progress for the full and incremental backup operations
+    parser.add_option("--progress", action="store_true")
+
+    # Used to control the progress option update rate in seconds. Default: prompts each 3 seconds
+    parser.add_option("--progress-rate", type="int", metavar=_("number"))
+
     # option to trigger Pydev debugger
     parser.add_option("--pydevd", action="store_true")
 
@@ -815,10 +826,13 @@ def usage():
   s3+http://%(bucket_name)s[/%(prefix)s]
   scp://%(user)s[:%(password)s]@%(other_host)s[:%(port)s]/%(some_dir)s
   ssh://%(user)s[:%(password)s]@%(other_host)s[:%(port)s]/%(some_dir)s
+  swift://%(container_name)s
   tahoe://%(alias)s/%(directory)s
   webdav://%(user)s[:%(password)s]@%(other_host)s/%(some_dir)s
   webdavs://%(user)s[:%(password)s]@%(other_host)s/%(some_dir)s
   gdocs://%(user)s[:%(password)s]@%(other_host)s/%(some_dir)s
+  mega://%(user)s[:%(password)s]@%(other_host)s/%(some_dir)s
+  dpbx:///%(some_dir)s
 
 """ % dict
 
