@@ -24,7 +24,7 @@
 import socket, os
 
 # The current version of duplicity
-version = "0.6.21"
+version = "0.6.22"
 
 # Default file_prefix value
 file_prefix = ""
@@ -75,6 +75,9 @@ gpg_profile = None
 # Options to pass to gpg
 gpg_options = ''
 
+# Maximum file blocksize
+max_blocksize = 2048L
+
 # If true, filelists and directory statistics will be split on
 # nulls instead of newlines.
 null_separator = None
@@ -241,3 +244,14 @@ extra_clean = False
 
 # Renames (--rename)
 rename = {}
+
+# enable data comparison on verify runs
+compare_data = False
+
+# When selected, triggers a dry-run before a full or incremental to compute
+# changes, then runs the real operation and keeps track of the real progress
+progress = False
+
+# Controls the upload progress messages refresh rate. Default: update each 
+# 3 seconds
+progress_rate = 3 
\ No newline at end of file
